@@ -3,8 +3,8 @@
 /**
  * @file classes/i18n/LanguageAction.inc.php
  *
- * Copyright (c) 2014-2016 Simon Fraser University Library
- * Copyright (c) 2003-2016 John Willinsky
+ * Copyright (c) 2014-2019 Simon Fraser University
+ * Copyright (c) 2003-2019 John Willinsky
  * Distributed under the GNU GPL v2. For full terms see the file docs/COPYING.
  *
  * @class LanguageAction
@@ -19,12 +19,6 @@ define('LANGUAGE_PACK_TAR_URL', 'http://pkp.sfu.ca/ojs/xml/%s/%s.tar.gz');
 import('lib.pkp.classes.i18n.PKPLanguageAction');
 
 class LanguageAction extends PKPLanguageAction {
-	/**
-	 * Constructor.
-	 */
-	function LanguageAction() {
-		parent::PKPLanguageAction();
-	}
 }
 
-?>
+
