@@ -8,8 +8,8 @@
 /**
  * @file classes/issue/Issue.inc.php
  *
- * Copyright (c) 2014-2016 Simon Fraser University Library
- * Copyright (c) 2003-2016 John Willinsky
+ * Copyright (c) 2014-2019 Simon Fraser University
+ * Copyright (c) 2003-2019 John Willinsky
  * Distributed under the GNU GPL v2. For full terms see the file docs/COPYING.
  *
  * @class Issue
@@ -345,60 +345,107 @@ class Issue extends DataObject {
 	}
 
 	/**
-	 * Get issue cover image file name
+	 * Get the localized issue cover image file name
 	 * @return string
 	 */
-	function getCoverImage() {
-		return $this->getData('coverImage');
+	function getLocalizedCoverImage() {
+		return $this->getLocalizedData('coverImage');
+	}
+
+	/**
+	 * Get issue cover image file name
+	 * @param $locale string
+	 * @return string
+	 */
+	function getCoverImage($locale) {
+		return $this->getData('coverImage', $locale);
 	}
 
 	/**
 	 * Set issue cover image file name
 	 * @param $coverImage string
+	 * @param $locale string
 	 */
-	function setCoverImage($coverImage) {
-		return $this->setData('coverImage', $coverImage);
+	function setCoverImage($coverImage, $locale) {
+		return $this->setData('coverImage', $coverImage, $locale);
+	}
+
+	/**
+	 * Get the localized issue cover image alternate text
+	 * @return string
+	 */
+	function getLocalizedCoverImageAltText() {
+		return $this->getLocalizedData('coverImageAltText');
 	}
 
 	/**
 	 * Get issue cover image alternate text
+	 * @param $locale string
 	 * @return string
 	 */
-	function getCoverImageAltText() {
-		return $this->getData('coverImageAltText');
+	function getCoverImageAltText($locale) {
+		return $this->getData('coverImageAltText', $locale);
+	}
+
+	/**
+	 * Get a full URL to the localized cover image
+	 *
+	 * @return string
+	 */
+	function getLocalizedCoverImageUrl() {
+		$coverImage = $this->getLocalizedCoverImage();
+		if (!$coverImage) {
+			return '';
+		}
+
+		$request = Application::getRequest();
+
+		import('classes.file.PublicFileManager');
+		$publicFileManager = new PublicFileManager();
+
+		return $request->getBaseUrl() . '/' . $publicFileManager->getJournalFilesPath($this->getJournalId()) . '/' . $coverImage;
+	}
+
+	/**
+	 * Get the full URL to all localized cover images
+	 *
+	 * @return array
+	 */
+	function getCoverImageUrls() {
+		$coverImages = $this->getCoverImage(null);
+		if (empty($coverImages)) {
+			return array();
+		}
+
+		$request = Application::getRequest();
+		import('classes.file.PublicFileManager');
+		$publicFileManager = new PublicFileManager();
+
+		$urls = array();
+
+		foreach ($coverImages as $locale => $coverImage) {
+			$urls[$locale] = sprintf('%s/%s/%s', $request->getBaseUrl(), $publicFileManager->getJournalFilesPath($this->getJournalId()), $coverImage);
+		}
+
+		return $urls;
 	}
 
 	/**
 	 * Set issue cover image alternate text
 	 * @param $coverImageAltText string
+	 * @param $locale string
 	 */
-	function setCoverImageAltText($coverImageAltText) {
-		return $this->setData('coverImageAltText', $coverImageAltText);
-	}
-
-	/**
-	 * Return string of author names, separated by the specified token
-	 * @param $lastOnly boolean return list of lastnames only (default false)
-	 * @param $separator string separator for names (default comma+space)
-	 * @return string
-	 */
-	function getAuthorString($lastOnly = false, $separator = ', ') {
-		$str = '';
-		foreach ($this->getAuthors() as $a) {
-			if (!empty($str)) {
-				$str .= $separator;
-			}
-			$str .= $lastOnly ? $a->getLastName() : $a->getFullName();
-		}
-		return $str;
+	function setCoverImageAltText($coverImageAltText, $locale) {
+		return $this->setData('coverImageAltText', $coverImageAltText, $locale);
 	}
 
 	/**
 	 * Return the string of the issue identification based label format
 	 * @param $force array force show/hide of data components
+	 * @param $locale string use spcific non-default locale
 	 * @return string
 	 */
-	function getIssueIdentification($force = array()) {
+	function getIssueIdentification($force = array(), $locale = null) {
 
 		$displayOptions = array(
 			'showVolume' => $this->getData('showVolume'),
@@ -408,15 +455,21 @@ class Issue extends DataObject {
 		);
 
 		$displayOptions = array_merge($displayOptions, $force);
+		if(is_null($locale)){
+			$locale = AppLocale::getLocale();
+		}
 
-		AppLocale::requireComponents(array(LOCALE_COMPONENT_APP_COMMON));
-		$volLabel = __('issue.vol');
-		$numLabel = __('issue.no');
+		AppLocale::requireComponents(array(LOCALE_COMPONENT_APP_COMMON), $locale);
+		$volLabel = PKPLocale::translate('issue.vol', array(), $locale);
+		$numLabel = PKPLocale::translate('issue.no', array(), $locale);
 
 		$vol = $this->getData('volume');
 		$num = $this->getData('number');
 		$year = $this->getData('year');
-		$title = $this->getLocalizedTitle();
+		$title = $this->getTitle($locale);
+		if(empty($title)){
+			$title = $this->getLocalizedTitle();
+		}
 
 		$identification = array();
 		foreach($displayOptions as $opt => $val) {
@@ -451,7 +504,8 @@ class Issue extends DataObject {
 					'showNumber' => true,
 					'showYear' => true,
 					'showTitle' => false,
-				)
+				),
+				$locale
 			);
 		}
 
@@ -464,7 +518,10 @@ class Issue extends DataObject {
 	 * @return string
 	 */
 	function getIssueSeries() {
-		return $this->getIssueIdentification(array('showTitle' => false));
+		if ($this->getShowVolume() || $this->getShowNumber() || $this->getShowYear()) {
+			return $this->getIssueIdentification(array('showTitle' => false));
+		}
+		return null;
 	}
 
 	/**
@@ -504,4 +561,4 @@ class Issue extends DataObject {
 	}
 }
 
-?>
+
