@@ -3,8 +3,8 @@
 /**
  * @file classes/journal/Section.inc.php
  *
- * Copyright (c) 2014-2016 Simon Fraser University Library
- * Copyright (c) 2003-2016 John Willinsky
+ * Copyright (c) 2014-2019 Simon Fraser University
+ * Copyright (c) 2003-2019 John Willinsky
  * Distributed under the GNU GPL v2. For full terms see the file docs/COPYING.
  *
  * @class Section
@@ -18,13 +18,6 @@ import('lib.pkp.classes.context.PKPSection');
 
 class Section extends PKPSection {
 
-	/**
-	 * Constructor.
-	 */
-	function Section() {
-		parent::PKPSection();
-	}
-
 	/**
 	 * Get localized abbreviation of journal section.
 	 * @return string
@@ -193,48 +186,4 @@ class Section extends PKPSection {
 	function setHideAuthor($hideAuthor) {
 		return $this->setData('hideAuthor', $hideAuthor);
 	}
-
-	/**
-	 * Return boolean indicating if title should be hidden in About.
-	 * @return boolean
-	 */
-	function getHideAbout() {
-		return $this->getData('hideAbout');
-	}
-
-	/**
-	 * Set if title should be hidden in About.
-	 * @param $hideAbout boolean
-	 */
-	function setHideAbout($hideAbout) {
-		return $this->setData('hideAbout', $hideAbout);
-	}
-
-	/**
-	 * Get localized section policy.
-	 * @return string
-	 */
-	function getLocalizedPolicy() {
-		return $this->getLocalizedData('policy');
-	}
-
-	/**
-	 * Get policy.
-	 * @param $locale string
-	 * @return string
-	 */
-	function getPolicy($locale) {
-		return $this->getData('policy', $locale);
-	}
-
-	/**
-	 * Set policy.
-	 * @param $policy string
-	 * @param $locale string
-	 */
-	function setPolicy($policy, $locale) {
-		return $this->setData('policy', $policy, $locale);
-	}
 }
-
-?>
