@@ -3,8 +3,8 @@
 /**
  * @file classes/subscription/SubscriptionTypeDAO.inc.php
  *
- * Copyright (c) 2014-2016 Simon Fraser University Library
- * Copyright (c) 2003-2016 John Willinsky
+ * Copyright (c) 2014-2019 Simon Fraser University
+ * Copyright (c) 2003-2019 John Willinsky
  * Distributed under the GNU GPL v2. For full terms see the file docs/COPYING.
  *
  * @class SubscriptionTypeDAO
@@ -18,40 +18,38 @@ import('classes.subscription.SubscriptionType');
 
 class SubscriptionTypeDAO extends DAO {
 	/**
-	 * Retrieve a subscription type by ID.
-	 * @param $typeId int
+	 * Create a new subscription type.
 	 * @return SubscriptionType
 	 */
-	function &getSubscriptionType($typeId) {
+	function newDataObject() {
+		return new SubscriptionType();
+	}
+
+	/**
+	 * Retrieve a subscription type by ID.
+	 * @param $typeId int
+	 * @param $journalId int optional
+	 * @return SubscriptionType
+	 */
+	function getById($typeId, $journalId = null) {
+		$params = array((int) $typeId);
+		if ($journalId) $params[] = (int) $journalId;
+
 		$result = $this->retrieve(
-			'SELECT * FROM subscription_types WHERE type_id = ?', $typeId
+			'SELECT * FROM subscription_types WHERE type_id = ?' .
+			($journalId?' AND journal_id = ?':''),
+			$params
 		);
 
 		$returner = null;
 		if ($result->RecordCount() != 0) {
-			$returner =& $this->_returnSubscriptionTypeFromRow($result->GetRowAssoc(false));
+			$returner = $this->_fromRow($result->GetRowAssoc(false));
 		}
 
 		$result->Close();
 		return $returner;
 	}
 
-	/**
-	 * Retrieve subscription type journal ID by ID.
-	 * @param $typeId int
-	 * @return int
-	 */
-	function getSubscriptionTypeJournalId($typeId) {
-		$result = $this->retrieve(
-			'SELECT journal_id FROM subscription_types WHERE type_id = ?', $typeId
-		);
-
-		$returner = isset($result->fields[0]) ? $result->fields[0] : false;	
-
-		$result->Close();
-		return $returner;
-	}
-
 	/**
 	 * Retrieve subscription type name by ID.
 	 * @param $typeId int
@@ -61,8 +59,8 @@ class SubscriptionTypeDAO extends DAO {
 		$result = $this->retrieve(
 			'SELECT COALESCE(l.setting_value, p.setting_value) FROM subscription_type_settings l LEFT JOIN subscription_type_settings p ON (p.type_id = ? AND p.setting_name = ? AND p.locale = ?) WHERE l.type_id = ? AND l.setting_name = ? AND l.locale = ?', 
 			array(
-				$typeId, 'name', AppLocale::getLocale(),
-				$typeId, 'name', AppLocale::getPrimaryLocale()
+				(int) $typeId, 'name', AppLocale::getLocale(),
+				(int) $typeId, 'name', AppLocale::getPrimaryLocale()
 			)
 		);
 
@@ -79,7 +77,7 @@ class SubscriptionTypeDAO extends DAO {
 	 */
 	function getSubscriptionTypeInstitutional($typeId) {
 		$result = $this->retrieve(
-			'SELECT institutional FROM subscription_types WHERE type_id = ?', $typeId
+			'SELECT institutional FROM subscription_types WHERE type_id = ?', (int) $typeId
 		);
 
 		$returner = isset($result->fields[0]) ? $result->fields[0] : false;
@@ -95,23 +93,7 @@ class SubscriptionTypeDAO extends DAO {
 	 */
 	function getSubscriptionTypeMembership($typeId) {
 		$result = $this->retrieve(
-			'SELECT membership FROM subscription_types WHERE type_id = ?', $typeId
-		);
-
-		$returner = isset($result->fields[0]) ? $result->fields[0] : false;
-
-		$result->Close();
-		return $returner;
-	}
-
-	/**
-	 * Retrieve nonExpiring flag by ID.
-	 * @param $typeId int
-	 * @return int
-	 */
-	function getSubscriptionTypeNonExpiring($typeId) {
-		$result = $this->retrieve(
-			'SELECT non_expiring FROM subscription_types WHERE type_id = ?', $typeId
+			'SELECT membership FROM subscription_types WHERE type_id = ?', (int) $typeId
 		);
 
 		$returner = isset($result->fields[0]) ? $result->fields[0] : false;
@@ -127,7 +109,7 @@ class SubscriptionTypeDAO extends DAO {
 	 */
 	function getSubscriptionTypeDisablePublicDisplay($typeId) {
 		$result = $this->retrieve(
-			'SELECT disable_public_display FROM subscription_types WHERE type_id = ?', $typeId
+			'SELECT disable_public_display FROM subscription_types WHERE type_id = ?', (int) $typeId
 		);
 
 		$returner = isset($result->fields[0]) ? $result->fields[0] : false;
@@ -149,8 +131,8 @@ class SubscriptionTypeDAO extends DAO {
 				WHERE type_id = ?
 				AND   journal_id = ?',
 			array(
-				$typeId,
-				$journalId
+				(int) $typeId,
+				(int) $journalId
 			)
 		);
 		$returner = isset($result->fields[0]) && $result->fields[0] != 0 ? true : false;
@@ -164,13 +146,12 @@ class SubscriptionTypeDAO extends DAO {
 	 * @param $row array
 	 * @return SubscriptionType
 	 */
-	function &_returnSubscriptionTypeFromRow($row) {
-		$subscriptionType = new SubscriptionType();
-		$subscriptionType->setTypeId($row['type_id']);
+	function _fromRow($row) {
+		$subscriptionType = $this->newDataObject();
+		$subscriptionType->setId($row['type_id']);
 		$subscriptionType->setJournalId($row['journal_id']);
 		$subscriptionType->setCost($row['cost']);
 		$subscriptionType->setCurrencyCodeAlpha($row['currency_code_alpha']);
-		$subscriptionType->setNonExpiring($row['non_expiring']);
 		$subscriptionType->setDuration($row['duration']);
 		$subscriptionType->setFormat($row['format']);
 		$subscriptionType->setInstitutional($row['institutional']);
@@ -180,7 +161,7 @@ class SubscriptionTypeDAO extends DAO {
 
 		$this->getDataObjectSettings('subscription_type_settings', 'type_id', $row['type_id'], $subscriptionType);
 
-		HookRegistry::call('SubscriptionTypeDAO::_returnSubscriptionTypeFromRow', array(&$subscriptionType, &$row));
+		HookRegistry::call('SubscriptionTypeDAO::_fromRow', array(&$subscriptionType, &$row));
 
 		return $subscriptionType;
 	}
@@ -197,55 +178,52 @@ class SubscriptionTypeDAO extends DAO {
 	 * Update the localized settings for this object
 	 * @param $subscriptionType object
 	 */
-	function updateLocaleFields(&$subscriptionType) {
+	function updateLocaleFields($subscriptionType) {
 		$this->updateDataObjectSettings('subscription_type_settings', $subscriptionType, array(
-			'type_id' => $subscriptionType->getTypeId()
+			'type_id' => $subscriptionType->getId()
 		));
 	}
 
 	/**
 	 * Insert a new SubscriptionType.
 	 * @param $subscriptionType SubscriptionType
-	 * @return boolean 
+	 * @return int Inserted subscription type ID
 	 */
-	function insertSubscriptionType(&$subscriptionType) {
+	function insertObject($subscriptionType) {
 		$this->update(
 			'INSERT INTO subscription_types
-				(journal_id, cost, currency_code_alpha, non_expiring, duration, format, institutional, membership, disable_public_display, seq)
+				(journal_id, cost, currency_code_alpha, duration, format, institutional, membership, disable_public_display, seq)
 				VALUES
-				(?, ?, ?, ?, ?, ?, ?, ?, ?, ?)',
+				(?, ?, ?, ?, ?, ?, ?, ?, ?)',
 			array(
-				$subscriptionType->getJournalId(),
-				$subscriptionType->getCost(),
+				(int) $subscriptionType->getJournalId(),
+				(float) $subscriptionType->getCost(),
 				$subscriptionType->getCurrencyCodeAlpha(),
-				$subscriptionType->getNonExpiring(),
 				$subscriptionType->getDuration(),
 				$subscriptionType->getFormat(),
-				$subscriptionType->getInstitutional(),
+				(int) $subscriptionType->getInstitutional(),
 				$subscriptionType->getMembership(),
-				$subscriptionType->getDisablePublicDisplay(),
-				$subscriptionType->getSequence()
+				(int) $subscriptionType->getDisablePublicDisplay(),
+				(float) $subscriptionType->getSequence(),
 			)
 		);
 
-		$subscriptionType->setTypeId($this->getInsertId());
+		$subscriptionType->setId($this->getInsertId());
 		$this->updateLocaleFields($subscriptionType);
-		return $subscriptionType->getTypeId();
+		return $subscriptionType->getId();
 	}
 
 	/**
 	 * Update an existing subscription type.
 	 * @param $subscriptionType SubscriptionType
-	 * @return boolean
 	 */
-	function updateSubscriptionType(&$subscriptionType) {
-		$returner = $this->update(
+	function updateObject($subscriptionType) {
+		$this->update(
 			'UPDATE subscription_types
 				SET
 					journal_id = ?,
 					cost = ?,
 					currency_code_alpha = ?,
-					non_expiring = ?,
 					duration = ?,
 					format = ?,
 					institutional = ?,
@@ -254,89 +232,57 @@ class SubscriptionTypeDAO extends DAO {
 					seq = ?
 				WHERE type_id = ?',
 			array(
-				$subscriptionType->getJournalId(),
+				(int) $subscriptionType->getJournalId(),
 				$subscriptionType->getCost(),
 				$subscriptionType->getCurrencyCodeAlpha(),
-				$subscriptionType->getNonExpiring(),
 				$subscriptionType->getDuration(),
 				$subscriptionType->getFormat(),
-				$subscriptionType->getInstitutional(),
+				(int) $subscriptionType->getInstitutional(),
 				$subscriptionType->getMembership(),
-				$subscriptionType->getDisablePublicDisplay(),
-				$subscriptionType->getSequence(),
-				$subscriptionType->getTypeId()
+				(int) $subscriptionType->getDisablePublicDisplay(),
+				(float) $subscriptionType->getSequence(),
+				(int) $subscriptionType->getId(),
 			)
 		);
 		$this->updateLocaleFields($subscriptionType);
-		return $returner;
-	}
-
-	/**
-	 * Delete a subscription type.
-	 * @param $subscriptionType SubscriptionType
-	 * @return boolean 
-	 */
-	function deleteSubscriptionType(&$subscriptionType) {
-		return $this->deleteSubscriptionTypeById($subscriptionType->getTypeId());
 	}
 
 	/**
 	 * Delete a subscription type by ID. Note that all subscriptions with this
 	 * type ID are also deleted.
-	 * @param $typeId int
-	 * @return boolean
+	 * @param $typeId int Subscription type ID
+	 * @param $journalId int Optional journal ID
 	 */
-	function deleteSubscriptionTypeById($typeId) {
-		// Delete all subscriptions corresponding to this subscription type
-		$institutional = $this->getSubscriptionTypeInstitutional($typeId);
-
-		if ($institutional) {
-			$subscriptionDao = DAORegistry::getDAO('InstitutionalSubscriptionDAO');
-		} else {
-			$subscriptionDao = DAORegistry::getDAO('IndividualSubscriptionDAO');
+	function deleteById($typeId, $journalId = null) {
+		$subscriptionType = $this->getById($typeId, $journalId);
+		if ($subscriptionType) {
+			$subscriptionDao = DAORegistry::getDAO($subscriptionType->getInstitutional()?'InstitutionalSubscriptionDAO':'IndividualSubscriptionDAO');
+			$subscriptionDao->deleteById($typeId);
+			$this->update('DELETE FROM subscription_types WHERE type_id = ?', (int) $typeId);
+			$this->update('DELETE FROM subscription_type_settings WHERE type_id = ?', (int) $typeId);
 		}
-		$returner = $subscriptionDao->deleteSubscriptionsByTypeId($typeId);
-
-		// Delete subscription type
-		if ($returner) {
-			$returner = $this->update('DELETE FROM subscription_types WHERE type_id = ?', $typeId);
-		}
-
-		// Delete all localization settings for this subscription type
-		if ($returner) {
-			$this->update('DELETE FROM subscription_type_settings WHERE type_id = ?', $typeId);
-		}
-
-		return $returner;
 	}
 
 	/**
 	 * Delete subscription types by journal ID. Note that all subscriptions with
 	 * corresponding types are also deleted.
 	 * @param $journalId int
-	 * @return boolean
 	 */
-	function deleteSubscriptionTypesByJournal($journalId) {
+	function deleteByJournal($journalId) {
 		$result = $this->retrieve(
 			'SELECT type_id
 			 FROM   subscription_types
 			 WHERE  journal_id = ?',
-			 $journalId
+			 (int) $journalId
 		);
-
-		$returner = false;
-
 		if ($result->RecordCount() != 0) {
-			$returner = true;
 			while (!$result->EOF && $returner) {
 				$typeId = $result->fields[0];
 				$returner = $this->deleteSubscriptionTypeById($typeId);
 				$result->MoveNext();
 			}
 		}
-
 		$result->Close();
-		return $returner;
 	}
 
 	/**
@@ -344,51 +290,36 @@ class SubscriptionTypeDAO extends DAO {
 	 * @param $journalId int
 	 * @return object DAOResultFactory containing matching SubscriptionTypes
 	 */
-	function &getSubscriptionTypesByJournalId($journalId, $rangeInfo = null) {
+	function getByJournalId($journalId, $rangeInfo = null) {
 		$result = $this->retrieveRange(
 			'SELECT * FROM subscription_types WHERE journal_id = ? ORDER BY seq',
-			$journalId, $rangeInfo
+			(int) $journalId, $rangeInfo
 		);
 
-		$returner = new DAOResultFactory($result, $this, '_returnSubscriptionTypeFromRow');
-		return $returner;
+		return new DAOResultFactory($result, $this, '_fromRow');
 	}
 
 	/**
 	 * Retrieve subscription types matching a particular journal ID and institutional flag.
 	 * @param $journalId int
 	 * @param $institutional bool
-	 * @param $disablePublicDisplay bool
+	 * @param $disablePublicDisplay bool|null
 	 * @return object DAOResultFactory containing matching SubscriptionTypes
 	 */
-	function &getSubscriptionTypesByInstitutional($journalId, $institutional = false, $disablePublicDisplay = null, $rangeInfo = null) {
-		if ($institutional) $institutional = 1; else $institutional = 0;
-
-		if ($disablePublicDisplay === null) {
-			$disablePublicDisplaySql = '';
-		} elseif ($disablePublicDisplay) {
-			$disablePublicDisplaySql = 'AND disable_public_display = 1';
-		} else {
-			$disablePublicDisplaySql = 'AND disable_public_display = 0';
-		}
-
+	function getByInstitutional($journalId, $institutional = false, $disablePublicDisplay = null, $rangeInfo = null) {
 		$result = $this->retrieveRange(
-			'SELECT *
-			FROM
-			subscription_types
-			WHERE journal_id = ?
-			AND institutional = ? '
-			. $disablePublicDisplaySql .
-			' ORDER BY seq',
-			array(
-				$journalId,
-				$institutional
-			),
+			'SELECT	*
+			FROM subscription_types
+			WHERE	journal_id = ?
+				AND institutional = ?
+				' . ($disablePublicDisplay===true?'AND disable_public_display = 1':'') . '
+				' . ($disablePublicDisplay===false?'AND disable_public_display = 0':'') . '
+			ORDER BY seq',
+			array((int) $journalId, (int) $institutional),
 			$rangeInfo
-			);
+		);
 
-		$returner = new DAOResultFactory($result, $this, '_returnSubscriptionTypeFromRow');
-		return $returner;
+		return new DAOResultFactory($result, $this, '_fromRow');
 	}
 
 	/**
@@ -398,22 +329,15 @@ class SubscriptionTypeDAO extends DAO {
 	 * @return boolean
 	 */
 	function subscriptionTypesExistByInstitutional($journalId, $institutional = false) {
-		if ($institutional) $institutional = 1; else $institutional = 0;
-
 		$result = $this->retrieve(
 			'SELECT COUNT(*)
 			FROM
 			subscription_types st
 			WHERE st.journal_id = ?
 			AND st.institutional = ?',
-			array(
-				$journalId,
-				$institutional
-			)
+			array((int) $journalId, (int) $institutional)
 		);
-
 		$returner = isset($result->fields[0]) && $result->fields[0] != 0 ? true : false;
-
 		$result->Close();
 		return $returner;
 	}
@@ -432,7 +356,7 @@ class SubscriptionTypeDAO extends DAO {
 	function resequenceSubscriptionTypes($journalId) {
 		$result = $this->retrieve(
 			'SELECT type_id FROM subscription_types WHERE journal_id = ? ORDER BY seq',
-			$journalId
+			(int) $journalId
 		);
 
 		for ($i=1; !$result->EOF; $i++) {
@@ -440,8 +364,8 @@ class SubscriptionTypeDAO extends DAO {
 			$this->update(
 				'UPDATE subscription_types SET seq = ? WHERE type_id = ?',
 				array(
-					$i,
-					$subscriptionTypeId
+					(int) $i,
+					(int) $subscriptionTypeId
 				)
 			);
 
@@ -452,4 +376,4 @@ class SubscriptionTypeDAO extends DAO {
 	}
 }
 
-?>
+
