@@ -3,8 +3,8 @@
 /**
  * @file controllers/tab/settings/reviewStage/form/ReviewStageForm.inc.php
  *
- * Copyright (c) 2014-2016 Simon Fraser University Library
- * Copyright (c) 2003-2016 John Willinsky
+ * Copyright (c) 2014-2019 Simon Fraser University
+ * Copyright (c) 2003-2019 John Willinsky
  * Distributed under the GNU GPL v2. For full terms see the file docs/COPYING.
  *
  * @class ReviewStageForm
@@ -20,8 +20,8 @@ class ReviewStageForm extends PKPReviewStageForm {
 	/**
 	 * Constructor.
 	 */
-	function ReviewStageForm($wizardMode = false) {
-		parent::PKPReviewStageForm(
+	function __construct($wizardMode = false) {
+		parent::__construct(
 			$wizardMode,
 			array(
 				'restrictReviewerFileAccess' => 'bool',
@@ -32,4 +32,4 @@ class ReviewStageForm extends PKPReviewStageForm {
 	}
 }
 
-?>
+
