@@ -3,8 +3,8 @@
 /**
  * @file classes/core/PKPRouter.inc.php
  *
- * Copyright (c) 2014-2016 Simon Fraser University Library
- * Copyright (c) 2000-2016 John Willinsky
+ * Copyright (c) 2014-2019 Simon Fraser University
+ * Copyright (c) 2000-2019 John Willinsky
  * Distributed under the GNU GPL v2. For full terms see the file docs/COPYING.
  *
  * @class PKPRouter
@@ -74,11 +74,13 @@ class PKPRouter {
 	var $_contextPaths = array();
 	/** @var integer contexts */
 	var $_contexts = array();
+	/** @var PKPHandler Handler class */
+	var $_handler;
 
 	/**
 	 * Constructor
 	 */
-	function PKPRouter() {
+	function __construct() {
 	}
 
 	/**
@@ -94,8 +96,8 @@ class PKPRouter {
 	 * set the application
 	 * @param $application PKPApplication
 	 */
-	function setApplication(&$application) {
-		$this->_application =& $application;
+	function setApplication($application) {
+		$this->_application = $application;
 
 		// Retrieve context depth and list
 		$this->_contextDepth = $application->getContextDepth();
@@ -120,6 +122,22 @@ class PKPRouter {
 		$this->_dispatcher = $dispatcher;
 	}
 
+	/**
+	 * Set the handler object for later retrieval.
+	 * @param $handler PKPHandler
+	 */
+	function setHandler($handler) {
+		$this->_handler = $handler;
+	}
+
+	/**
+	 * Get the handler object.
+	 * @return PKPHandler
+	 */
+	function getHandler() {
+		return $this->_handler;
+	}
+
 	/**
 	 * Determines whether this router can route the given request.
 	 * @param $request PKPRequest
@@ -385,7 +403,10 @@ class PKPRouter {
 
 		// Return the result of the operation to the client.
 		if (is_string($result)) echo $result;
-		elseif (is_a($result, 'JSONMessage')) echo $result->getString();
+		elseif (is_a($result, 'JSONMessage')) {
+			header('Content-Type: application/json');
+			echo $result->getString();
+		}
 	}
 
 	/**
@@ -606,4 +627,4 @@ class PKPRouter {
 	}
 }
 
-?>
+
