@@ -3,8 +3,8 @@
 /**
  * @file classes/form/validation/FormValidatorInSet.inc.php
  *
- * Copyright (c) 2014-2016 Simon Fraser University Library
- * Copyright (c) 2000-2016 John Willinsky
+ * Copyright (c) 2014-2019 Simon Fraser University
+ * Copyright (c) 2000-2019 John Willinsky
  * Distributed under the GNU GPL v2. For full terms see the file docs/COPYING.
  *
  * @class FormValidatorInSet
@@ -28,8 +28,8 @@ class FormValidatorInSet extends FormValidator {
 	 * @param $message string the error message for validation failures (i18n key)
 	 * @param $acceptedValues array all possible accepted values
 	 */
-	function FormValidatorInSet(&$form, $field, $type, $message, $acceptedValues) {
-		parent::FormValidator($form, $field, $type, $message);
+	function __construct(&$form, $field, $type, $message, $acceptedValues) {
+		parent::__construct($form, $field, $type, $message);
 		$this->_acceptedValues = $acceptedValues;
 	}
 
@@ -47,4 +47,4 @@ class FormValidatorInSet extends FormValidator {
 	}
 }
 
-?>
+
