@@ -3,8 +3,8 @@
 /**
  * @file classes/form/validation/FormValidatorUri.inc.php
  *
- * Copyright (c) 2014-2016 Simon Fraser University Library
- * Copyright (c) 2000-2016 John Willinsky
+ * Copyright (c) 2014-2019 Simon Fraser University
+ * Copyright (c) 2000-2019 John Willinsky
  * Distributed under the GNU GPL v2. For full terms see the file docs/COPYING.
  *
  * @class FormValidatorUri
@@ -26,10 +26,10 @@ class FormValidatorUri extends FormValidator {
 	 * @param $message string the error message for validation failures (i18n key)
 	 * @param $allowedSchemes array the allowed URI schemes
 	 */
-	function FormValidatorUri(&$form, $field, $type, $message, $allowedSchemes = null) {
+	function __construct(&$form, $field, $type, $message, $allowedSchemes = null) {
 		import('lib.pkp.classes.validation.ValidatorUri');
 		$validator = new ValidatorUri($allowedSchemes);
-		parent::FormValidator($form, $field, $type, $message, $validator);
+		parent::__construct($form, $field, $type, $message, $validator);
 	}
 }
-?>
+
