@@ -3,8 +3,8 @@
 /**
  * @file classes/log/SubmissionFileEventLogDAO.inc.php
  *
- * Copyright (c) 2014-2016 Simon Fraser University Library
- * Copyright (c) 2003-2016 John Willinsky
+ * Copyright (c) 2014-2019 Simon Fraser University
+ * Copyright (c) 2003-2019 John Willinsky
  * Distributed under the GNU GPL v2. For full terms see the file docs/COPYING.
  *
  * @class SubmissionFileEventLogDAO
@@ -18,12 +18,6 @@ import('lib.pkp.classes.log.EventLogDAO');
 import('lib.pkp.classes.log.SubmissionFileEventLogEntry');
 
 class SubmissionFileEventLogDAO extends EventLogDAO {
-	/**
-	 * Constructor
-	 */
-	function SubmissionFileEventLogDAO() {
-		parent::EventLogDAO();
-	}
 
 	/**
 	 * Instantiate a submission file event log entry.
@@ -45,4 +39,4 @@ class SubmissionFileEventLogDAO extends EventLogDAO {
 	}
 }
 
-?>
+
