@@ -9,8 +9,8 @@
 /**
  * @file classes/oai/OAI.inc.php
  *
- * Copyright (c) 2014-2016 Simon Fraser University Library
- * Copyright (c) 2000-2016 John Willinsky
+ * Copyright (c) 2014-2019 Simon Fraser University
+ * Copyright (c) 2000-2019 John Willinsky
  * Distributed under the GNU GPL v2. For full terms see the file docs/COPYING.
  *
  * @class OAI
@@ -40,7 +40,7 @@ abstract class OAI {
 	 * Initializes object and parses user input.
 	 * @param $config OAIConfig repository configuration
 	 */
-	function OAI($config) {
+	function __construct($config) {
 		$this->config = $config;
 
 		// Initialize parameters from GET or POST variables
@@ -796,7 +796,7 @@ abstract class OAI {
 	 */
 	function extractDateParams($params, &$from, &$until) {
 		if (isset($params['from'])) {
-			$from = OAIUtils::UTCtoTimestamp($params['from']);
+			$from = OAIUtils::UTCtoTimestamp($params['from'], $this->config->granularity);
 
 			if ($from == 'invalid') {
 				$this->error('badArgument', 'Illegal from parameter');
@@ -809,7 +809,7 @@ abstract class OAI {
 		}
 
 		if(isset($params['until'])) {
-			$until = OAIUtils::UTCtoTimestamp($params['until']);
+			$until = OAIUtils::UTCtoTimestamp($params['until'], $this->config->granularity);
 
 			if($until == 'invalid') {
 				$this->error('badArgument', 'Illegal until parameter');
@@ -842,4 +842,4 @@ abstract class OAI {
 	}
 }
 
-?>
+
