@@ -3,8 +3,8 @@
 /**
  * @file classes/submission/SubmissionDAO.inc.php
  *
- * Copyright (c) 2014-2016 Simon Fraser University Library
- * Copyright (c) 2003-2016 John Willinsky
+ * Copyright (c) 2014-2019 Simon Fraser University
+ * Copyright (c) 2003-2019 John Willinsky
  * Distributed under the GNU GPL v2. For full terms see the file docs/COPYING.
  *
  * @class SubmissionDAO
@@ -17,6 +17,9 @@
 import('lib.pkp.classes.submission.Submission');
 import('lib.pkp.classes.plugins.PKPPubIdPluginDAO');
 
+define('ORDERBY_DATE_PUBLISHED', 'datePublished');
+define('ORDERBY_TITLE', 'title');
+
 abstract class SubmissionDAO extends DAO implements PKPPubIdPluginDAO {
 	var $cache;
 	var $authorDao;
@@ -24,8 +27,8 @@ abstract class SubmissionDAO extends DAO implements PKPPubIdPluginDAO {
 	/**
 	 * Constructor.
 	 */
-	function SubmissionDAO() {
-		parent::DAO();
+	function __construct() {
+		parent::__construct();
 		$this->authorDao = DAORegistry::getDAO('AuthorDAO');
 	}
 
@@ -33,7 +36,7 @@ abstract class SubmissionDAO extends DAO implements PKPPubIdPluginDAO {
 	 * Callback for a cache miss.
 	 * @param $cache Cache
 	 * @param $id string
-	 * @return Monograph
+	 * @return Submission
 	 */
 	function _cacheMiss($cache, $id) {
 		$submission = $this->getById($id, null, false);
@@ -79,8 +82,6 @@ abstract class SubmissionDAO extends DAO implements PKPPubIdPluginDAO {
 				'pub-id::publisher-id', // FIXME: Move this to a PID plug-in.
 				'copyrightYear',
 				'licenseURL',
-				'coverImage',
-				'coverImageAltText',
 			)
 		);
 	}
@@ -89,9 +90,7 @@ abstract class SubmissionDAO extends DAO implements PKPPubIdPluginDAO {
 	 * Instantiate a new data object.
 	 * @return Submission
 	 */
-	function newDataObject() {
-		return new Submission();
-	}
+	abstract function newDataObject();
 
 	/**
 	 * Internal function to return a Submission object from a row.
@@ -109,10 +108,9 @@ abstract class SubmissionDAO extends DAO implements PKPPubIdPluginDAO {
 		$submission->setSubmissionProgress($row['submission_progress']);
 		$submission->setDateSubmitted($this->datetimeFromDB($row['date_submitted']));
 		$submission->setDateStatusModified($this->datetimeFromDB($row['date_status_modified']));
-		$submission->setDatePublished($this->datetimeFromDB($row['date_published']));
+		$submission->setDatePublished(isset($row['date_published']) ? $this->datetimeFromDB($row['date_published']) : null);
 		$submission->setLastModified($this->datetimeFromDB($row['last_modified']));
 		$submission->setLanguage($row['language']);
-		$submission->setCommentsToEditor($row['comments_to_ed']);
 		$submission->setCitations($row['citations']);
 
 		$this->getDataObjectSettings('submission_settings', 'submission_id', $submission->getId(), $submission);
@@ -136,6 +134,12 @@ abstract class SubmissionDAO extends DAO implements PKPPubIdPluginDAO {
 		// Delete submission files.
 		$submission = $this->getById($submissionId);
 		assert(is_a($submission, 'Submission'));
+		// 'deleteAllRevisionsBySubmissionId' has to be called before 'rmtree'
+		// because SubmissionFileDaoDelegate::deleteObjects checks the file
+		// and returns false if the file is not there, which makes the foreach loop in
+		// SubmissionFileDAO::_deleteInternally not run till the end.
+		$submissionFileDao = DAORegistry::getDAO('SubmissionFileDAO'); /* @var $submissionFileDao SubmissionFileDAO */
+		$submissionFileDao->deleteAllRevisionsBySubmissionId($submissionId);
 		import('lib.pkp.classes.file.SubmissionFileManager');
 		$submissionFileManager = new SubmissionFileManager($submission->getContextId(), $submission->getId());
 		$submissionFileManager->rmtree($submissionFileManager->getBasePath());
@@ -162,10 +166,6 @@ abstract class SubmissionDAO extends DAO implements PKPPubIdPluginDAO {
 			$stageAssignmentDao->deleteObject($stageAssignment);
 		}
 
-		// Delete submission files.
-		$submissionFileDao = DAORegistry::getDAO('SubmissionFileDAO'); /* @var $submissionFileDao SubmissionFileDAO */
-		$submissionFileDao->deleteAllRevisionsBySubmissionId($submissionId);
-
 		$noteDao = DAORegistry::getDAO('NoteDAO');
 		$noteDao->deleteByAssoc(ASSOC_TYPE_SUBMISSION, $submissionId);
 
@@ -220,7 +220,7 @@ abstract class SubmissionDAO extends DAO implements PKPPubIdPluginDAO {
 	/**
 	 * @copydoc PKPPubIdPluginDAO::pubIdExists()
 	 */
-	function pubIdExists($pubIdType, $pubId, $submissionId, $contextId) {
+	function pubIdExists($pubIdType, $pubId, $excludePubObjectId, $contextId) {
 		$result = $this->retrieve(
 			'SELECT COUNT(*)
 			FROM submission_settings sst
@@ -229,7 +229,7 @@ abstract class SubmissionDAO extends DAO implements PKPPubIdPluginDAO {
 			array(
 				'pub-id::'.$pubIdType,
 				$pubId,
-				(int) $submissionId,
+				(int) $excludePubObjectId,
 				(int) $contextId
 			)
 		);
@@ -238,15 +238,55 @@ abstract class SubmissionDAO extends DAO implements PKPPubIdPluginDAO {
 		return $returner;
 	}
 
+	/**
+	 * Stamp a submission status modification date.
+	 * This updates both the supplied Submission object and the database.
+	 * @param $submission Submission
+	 */
+	public function stampStatusModified($submission) {
+		// Stamp the active submission object
+		$submission->stampStatusModified();
+
+		// Stamp the database entry
+		$this->update(
+			sprintf(
+				'UPDATE submissions SET date_status_modified = %s WHERE submission_id = ?',
+				$this->datetimeToDB($submission->getDateStatusModified())
+			),
+			array((int) $submission->getId())
+		);
+
+		$this->stampModified($submission);
+	}
+
+	/**
+	 * Stamp a submission modification date.
+	 * This updates both the supplied Submission object and the database.
+	 * @param $submission Submission
+	 */
+	public function stampModified($submission) {
+		// Stamp the active submission object
+		$submission->stampModified();
+
+		// Stamp the database entry
+		$this->update(
+			sprintf(
+				'UPDATE submissions SET last_modified = %s WHERE submission_id = ?',
+				$this->datetimeToDB($submission->getLastModified())
+			),
+			array((int) $submission->getId())
+		);
+	}
+
 	/**
 	 * @copydoc PKPPubIdPluginDAO::changePubId()
 	 */
-	function changePubId($submissionId, $pubIdType, $pubId) {
+	function changePubId($pubObjectId, $pubIdType, $pubId) {
 		$idFields = array(
 			'submission_id', 'locale', 'setting_name'
 		);
 		$updateArray = array(
-			'submission_id' => (int) $submissionId,
+			'submission_id' => (int) $pubObjectId,
 			'locale' => '',
 			'setting_name' => 'pub-id::'.$pubIdType,
 			'setting_type' => 'string',
@@ -259,13 +299,13 @@ abstract class SubmissionDAO extends DAO implements PKPPubIdPluginDAO {
 	/**
 	 * @copydoc PKPPubIdPluginDAO::deletePubId()
 	 */
-	function deletePubId($submissionId, $pubIdType) {
+	function deletePubId($pubObjectId, $pubIdType) {
 		$settingName = 'pub-id::'.$pubIdType;
 		$this->update(
 			'DELETE FROM submission_settings WHERE setting_name = ? AND submission_id = ?',
 			array(
 				$settingName,
-				(int)$submissionId
+				(int)$pubObjectId
 			)
 		);
 		$this->flushCache();
@@ -275,18 +315,17 @@ abstract class SubmissionDAO extends DAO implements PKPPubIdPluginDAO {
 	 * @copydoc PKPPubIdPluginDAO::deleteAllPubIds()
 	 */
 	function deleteAllPubIds($contextId, $pubIdType) {
-		$contextId = (int) $contextId;
 		$settingName = 'pub-id::'.$pubIdType;
 
 		$submissions = $this->getByContextId($contextId);
 		while ($submission = $submissions->next()) {
 			$this->update(
-					'DELETE FROM submission_settings WHERE setting_name = ? AND submission_id = ?',
-					array(
-							$settingName,
-							(int)$submission->getId()
-					)
-					);
+				'DELETE FROM submission_settings WHERE setting_name = ? AND submission_id = ?',
+				array(
+					$settingName,
+					(int)$submission->getId()
+				)
+			);
 		}
 		$this->flushCache();
 	}
@@ -400,7 +439,8 @@ abstract class SubmissionDAO extends DAO implements PKPPubIdPluginDAO {
 				AND aug.user_group_id IS NULL
 				AND s.date_submitted IS NOT NULL
 				AND s.status <> ' .  STATUS_DECLINED .
-				($contextId?' AND s.context_id = ?':''),
+				($contextId?' AND s.context_id = ?':'')
+			. ' ORDER BY s.submission_id',
 			$params
 		);
 
@@ -428,7 +468,8 @@ abstract class SubmissionDAO extends DAO implements PKPPubIdPluginDAO {
 			FROM	submissions s
 				LEFT JOIN published_submissions ps ON (s.submission_id = ps.submission_id)
 				' . $this->getFetchJoins() . '
-			WHERE	s.context_id = ?',
+			WHERE	s.context_id = ?
+			ORDER BY s.submission_id',
 			$params
 		);
 
@@ -455,375 +496,9 @@ abstract class SubmissionDAO extends DAO implements PKPPubIdPluginDAO {
 				LEFT JOIN published_submissions ps ON (s.submission_id = ps.submission_id)
 				' . $this->getFetchJoins() . '
 			WHERE	s.submission_id IN (SELECT asa.submission_id FROM stage_assignments asa, user_groups aug WHERE asa.user_group_id = aug.user_group_id AND aug.role_id = ? AND asa.user_id = ?)' .
-				($contextId?' AND s.context_id = ?':''),
-			$params
-		);
-
-		return new DAOResultFactory($result, $this, '_fromRow');
-	}
-
-	/**
-	 * Get all unassigned submissions for a context or all contexts
-	 * @param $contextId int optional the ID of the context to query.
-	 * @param $subEditorId int optional the ID of the sub editor
-	 *  whose section will be included in the results (excluding others).
-	 * @param $includeDeclined boolean optional include submissions which have STATUS_DECLINED
-	 * @param $includePublished boolean optional include submissions which are published
-	 * @param $title string|null optional Filter by title.
-	 * @param $author string|null optional Filter by author.
-	 * @param $stageId int|null optional Filter by stage id.
-	 * @param $rangeInfo DBRangeInfo
-	 * @return DAOResultFactory containing matching Submissions
-	 */
-	function getBySubEditorId($contextId, $subEditorId = null, $includeDeclined = true, $includePublished = true, $title = null, $author = null, $stageId = null, $rangeInfo = null) {
-		$params = $this->getFetchParameters();
-		if ($subEditorId) $params[] = (int) $subEditorId;
-		$params[] = (int) $contextId;
-		$params[] = (int) ROLE_ID_MANAGER;
-		$params[] = (int) ROLE_ID_SUB_EDITOR;
-
-		if ($title) {
-			$params[] = 'title';
-			$params[] = '%' . $title . '%';
-		}
-		if ($author) array_push($params, $authorQuery = '%' . $author . '%', $authorQuery, $authorQuery);
-		if ($stageId) $params[] = (int) $stageId;
-
-		$result = $this->retrieveRange(
-			'SELECT	s.*, ps.date_published,
-				' . $this->getFetchColumns() . '
-			FROM	submissions s
-				LEFT JOIN published_submissions ps ON s.submission_id = ps.submission_id
-				' . $this->getCompletionJoins() . '
-				' . ($title?' LEFT JOIN submission_settings ss ON (s.submission_id = ss.submission_id)':'') . '
-				' . ($author?' LEFT JOIN authors au ON (s.submission_id = au.submission_id)':'') . '
-				' . $this->getFetchJoins() . '
-				' . ($subEditorId?' ' . $this->getSubEditorJoin():'') . '
-			WHERE	s.date_submitted IS NOT NULL AND
-				s.context_id = ? AND
-				(SELECT COUNT(sa.stage_assignment_id) FROM stage_assignments sa LEFT JOIN user_groups g ON sa.user_group_id = g.user_group_id WHERE
-					sa.submission_id = s.submission_id AND (g.role_id = ? OR g.role_id = ?)) = 0'
-			. (!$includeDeclined?' AND s.status <> ' . STATUS_DECLINED : '' )
-			. (!$includePublished?' AND ' . $this->getCompletionConditions(false):'')
-			. ($contextId && is_array($contextId)?' AND s.context_id IN  (' . join(',', array_map(array($this,'_arrayWalkIntCast'), $contextId)) . ')':'')
-			. ($title?' AND (ss.setting_name = ? AND ss.setting_value LIKE ?)':'')
-			. ($author?' AND (au.first_name LIKE ? OR au.middle_name LIKE ? OR au.last_name LIKE ?)':'')
-			. ($stageId?' AND s.stage_id = ?':'') .
-			' GROUP BY ' . $this->getGroupByColumns(),
-			$params,
-			$rangeInfo
-		);
-
-		return new DAOResultFactory($result, $this, '_fromRow');
-	}
-
-	/**
-	 * Get all unpublished submissions for a user.
-	 * @param $userId int
-	 * @param $contextId int optional
-	 * @param $rangeInfo DBResultRange optional
-	 * @return array Submissions
-	 */
-	function getUnpublishedByUserId($userId, $contextId = null, $title = null, $stageId = null, $rangeInfo = null) {
-		$params = array_merge(
-			$this->getFetchParameters(),
-			array((int) ROLE_ID_AUTHOR, (int) $userId)
-		);
-		if ($title) $params[] = '%' . $title . '%';
-		if ($stageId) $params[] = (int) $stageId;
-		if ($contextId) $params[] = (int) $contextId;
-
-		$result = $this->retrieveRange(
-			'SELECT	s.*, ps.date_published,
-				' . $this->getFetchColumns() . '
-			FROM	submissions s
-				LEFT JOIN published_submissions ps ON (s.submission_id = ps.submission_id)' .
-				$this->getCompletionJoins() .
-				($title?' LEFT JOIN submission_settings ss ON (s.submission_id = ss.submission_id)':'') .
-				$this->getFetchJoins() .
-			'WHERE	s.submission_id IN (SELECT asa.submission_id FROM stage_assignments asa, user_groups aug WHERE asa.user_group_id = aug.user_group_id AND aug.role_id = ? AND asa.user_id = ?)' .
-				' AND ' . $this->getCompletionConditions(false) .
 				($contextId?' AND s.context_id = ?':'') .
-				($title?' AND (ss.setting_name = ? AND ss.setting_value LIKE ?)':'') .
-				($stageId?' AND s.stage_id = ?':'') .
-				' GROUP BY ' . $this->getGroupByColumns(),
-			$params, $rangeInfo
-		);
-
-		return new DAOResultFactory($result, $this, '_fromRow');
-	}
-
-	/**
-	 * Get all submissions that a reviewer denied a review request.
-	 * It will list only the submissions that a review has denied
-	 * ALL review assignments.
-	 * @param $reviewerId int
-	 * @param $contextId int optional
-	 * @param $title string optional
-	 * @param $author string optional
-	 * @param $stageId int optional
-	 * @param $rangeInfo DBResultRange optional
-	 * @return DAOResultFactory
-	 */
-	function getReviewerArchived($reviewerId, $contextId = null, $title = null, $author = null, $stageId = null, $rangeInfo = null) {
-		$params = array($reviewerId, $reviewerId);
-		$params = array_merge($params, $this->getFetchParameters());
-		$params[] = $reviewerId;
-		if ($title) {
-			$params[] = 'title';
-			$params[] = '%' . $title . '%';
-		}
-		if ($author) array_push($params, $authorQuery = '%' . $author . '%', $authorQuery, $authorQuery);
-		if ($stageId) $params[] = (int) $stageId;
-
-		$result = $this->retrieveRange(
-			'SELECT s.*, ps.date_published,
-				' . $this->getFetchColumns() . '
-			FROM	submissions s
-				LEFT JOIN published_submissions ps ON (s.submission_id = ps.submission_id)
-				LEFT JOIN review_assignments ra ON (s.submission_id = ra.submission_id AND ra.reviewer_id = ? AND ra.declined = true)
-				LEFT JOIN review_assignments ra2 ON (s.submission_id = ra2.submission_id AND ra2.reviewer_id = ? AND ra2.declined = true AND ra2.review_id > ra.review_id)
-				' . ($title?' LEFT JOIN submission_settings ss ON (s.submission_id = ss.submission_id)':'') . '
-				' . ($author?' LEFT JOIN authors au ON (s.submission_id = au.submission_id)':'')
-				. $this->getFetchJoins() .
-			' WHERE ra2.review_id IS NULL AND ra.review_id IS NOT NULL
-				AND (SELECT COUNT(ra3.review_id) FROM review_assignments ra3
-					WHERE s.submission_id = ra3.submission_id AND ra3.reviewer_id = ? AND ra3.declined = 0) = 0
-				' . ($contextId?' AND s.context_id IN  (' . join(',', array_map(array($this,'_arrayWalkIntCast'), (array) $contextId)) . ')':'')
-				. ($title?' AND (ss.setting_name = ? AND ss.setting_value LIKE ?)':'')
-				. ($author?' AND (au.first_name LIKE ? OR au.middle_name LIKE ? OR au.last_name LIKE ?)':'')
-				. ($stageId?' AND s.stage_id = ?':''),
-			$params,
-			$rangeInfo
-		);
-
-		return new DAOResultFactory($result, $this, '_fromRow');
-	}
-
-	/**
-	 * Get all submissions for a status.
-	 * @param $status int Status to get submissions for
-	 * @param $userId int optional User to require an assignment for
-	 * @param $contextId mixed optional Context(s) to fetch submissions for
-	 * @param $title string optional
-	 * @param $author string optional
-	 * @param $stageId int optional
-	 * @param $rangeInfo DBResultRange optional
-	 * @return DAOResultFactory
-	 */
-	function getByStatus($status, $userId = null, $contextId = null, $title = null, $author = null, $stageId = null, $rangeInfo = null) {
-		$params = array();
-
-		if ($userId) $params = array_merge(
-			$params,
-			array(
-				(int) $userId, // Stage assignments
-				(int) $userId, // sa2 to prevent dupes
-				(int) $userId, // Review assignments
-				(int) $userId, // ra2 to prevent dupes
-			)
-		);
-
-		$params = array_merge($params, $this->getFetchParameters());
-
-		if ($title) {
-			$params[] = 'title';
-			$params[] = '%' . $title . '%';
-		}
-		if ($author) array_push($params, $authorQuery = '%' . $author . '%', $authorQuery, $authorQuery);
-		if ($stageId) $params[] = (int) $stageId;
-
-		$result = $this->retrieveRange(
-			'SELECT	s.*, ps.date_published,
-				' . $this->getFetchColumns() . '
-			FROM	submissions s
-				LEFT JOIN published_submissions ps ON (s.submission_id = ps.submission_id)
-				' . ($userId?
-					'LEFT JOIN stage_assignments sa ON (s.submission_id = sa.submission_id AND sa.user_id = ?)
-					LEFT JOIN stage_assignments sa2 ON (s.submission_id = sa2.submission_id AND sa2.user_id = ? AND sa2.stage_assignment_id > sa.stage_assignment_id)
-					LEFT JOIN review_assignments ra ON (s.submission_id = ra.submission_id AND ra.reviewer_id = ?)
-					LEFT JOIN review_assignments ra2 ON (s.submission_id = ra2.submission_id AND ra2.reviewer_id = ? AND ra2.review_id > ra.review_id)'
-				:'') .
-				($title?' LEFT JOIN submission_settings ss ON (s.submission_id = ss.submission_id)':'') . '
-				' . ($author?' LEFT JOIN authors au ON (s.submission_id = au.submission_id)':'') .
-				$this->getFetchJoins() .
-			'WHERE
-				s.status IN  (' . join(',', array_map(array($this,'_arrayWalkIntCast'), (array) $status)) . ')
-				' . ($contextId?' AND s.context_id IN  (' . join(',', array_map(array($this,'_arrayWalkIntCast'), (array) $contextId)) . ')':'')
-				. ($userId?' AND sa2.stage_assignment_id IS NULL AND ra2.review_id IS NULL AND (sa.stage_assignment_id IS NOT NULL OR ra.review_id IS NOT NULL)':'')
-				. ($title?' AND (ss.setting_name = ? AND ss.setting_value LIKE ?)':'')
-				. ($author?' AND (au.first_name LIKE ? OR au.middle_name LIKE ? OR au.last_name LIKE ?)':'')
-				. ($stageId?' AND s.stage_id = ?':''),
-			$params,
-			$rangeInfo
-		);
-
-		return new DAOResultFactory($result, $this, '_fromRow');
-	}
-
-	/**
-	 * Get all submissions that are considered assigned to the passed user, excluding author participation.
-	 * @param $userId int
-	 * @param $contextId int optional
-	 * @param $title string|null optional Filter by title.
-	 * @param $author string|null optional Filter by author.
-	 * @param $stageId int|null optional Filter by stage id.
-	 * @param $rangeInfo DBResultRange optional
-	 * @return DAOResultFactory
-	 */
-	function getAssignedToUser($userId, $contextId = null, $title = null, $author = null, $stageId = null, $rangeInfo = null) {
-		$params = array_merge(
-			array(ROLE_ID_AUTHOR),
-			$this->getFetchParameters(),
-			array(
-				(int) STATUS_DECLINED,
-				(int) $userId,
-				(int) $userId
-			)
-		);
-		if ($contextId) $params[] = (int) $contextId;
-
-		if ($title) {
-			$params[] = 'title';
-			$params[] = '%' . $title . '%';
-		}
-		if ($author) array_push($params, $authorQuery = '%' . $author . '%', $authorQuery, $authorQuery);
-		if ($stageId) $params[] = (int) $stageId;
-
-		$result = $this->retrieveRange($sql =
-			'SELECT s.*, ps.date_published,
-				' . $this->getFetchColumns() . '
-			FROM submissions s
-				LEFT JOIN published_submissions ps ON (s.submission_id = ps.submission_id)
-				' . $this->getCompletionJoins() . '
-				LEFT JOIN stage_assignments sa ON (s.submission_id = sa.submission_id)
-				LEFT JOIN user_groups aug ON (sa.user_group_id = aug.user_group_id AND aug.role_id = ?)
-				LEFT JOIN submission_files sf ON (s.submission_id = sf.submission_id)
-				LEFT JOIN review_assignments ra ON (s.submission_id = ra.submission_id AND ra.declined = 0)
-				' . ($title?' LEFT JOIN submission_settings ss ON (s.submission_id = ss.submission_id)':'') . '
-				' . ($author?' LEFT JOIN authors au ON (s.submission_id = au.submission_id)':'')
-				. $this->getFetchJoins() .
-			' WHERE s.date_submitted IS NOT NULL
-				AND ' . $this->getCompletionConditions(false) . '
-				AND s.status <> ?
-				AND aug.user_group_id IS NULL
-				AND (sa.user_id = ? OR ra.reviewer_id = ?)'
-				. ($contextId?' AND s.context_id = ?':'')
-				. ($title?' AND (ss.setting_name = ? AND ss.setting_value LIKE ?)':'')
-				. ($author?' AND (ra.submission_id IS NULL AND (au.first_name LIKE ? OR au.middle_name LIKE ? OR au.last_name LIKE ?))':'') // Don't permit reviewer searching on author name
-				. ($stageId?' AND s.stage_id = ?':'') .
-			' GROUP BY ' . $this->getGroupByColumns(),
-			$params,
-			$rangeInfo
-		);
-
-		return new DAOResultFactory($result, $this, '_fromRow');
-	}
-
-	/**
-	 * Get all submissions that are assigned to users other than the passed one.
-	 * @param $userId int
-	 * @param $contextId int optional
-	 * @param $title string|null optional Filter by title.
-	 * @param $author string|null optional Filter by author.
-	 * @param $editor int|null optional Filter by editor name.
-	 * @param $stageId int|null optional Filter by stage id.
-	 * @param $rangeInfo DBResultRange optional
-	 * @return DAOResultFactory
-	 */
-	function getAssignedToOthers($userId, $contextId = null, $title = null, $author = null, $editor = null, $stageId = null, $rangeInfo = null) {
-		$params = $this->getFetchParameters();
-		$userId = (int) $userId;
-		array_push($params, (int) STATUS_DECLINED, $userId, (int) ROLE_ID_MANAGER, (int) ROLE_ID_SUB_EDITOR);
-		if ($editor) array_push($params, $editorQuery = '%' . $editor . '%', $editorQuery);
-		if ($contextId) $params[] = (int) $contextId;
-
-		if ($title) {
-			$params[] = 'title';
-			$params[] = '%' . $title . '%';
-		}
-		if ($author) array_push($params, $authorQuery = '%' . $author . '%', $authorQuery, $authorQuery);
-		if ($stageId) $params[] = (int) $stageId;
-
-		$result = $this->retrieveRange($sql =
-			'SELECT s.*, ps.date_published,
-				' . $this->getFetchColumns() . '
-			FROM submissions s
-				LEFT JOIN published_submissions ps ON (s.submission_id = ps.submission_id)
-				' . $this->getCompletionJoins() . '
-				LEFT JOIN submission_files sf ON (s.submission_id = sf.submission_id)
-				LEFT JOIN review_assignments ra ON (s.submission_id = ra.submission_id)
-				' . ($title?' LEFT JOIN submission_settings ss ON (s.submission_id = ss.submission_id)':'') . '
-				' . ($author?' LEFT JOIN authors au ON (s.submission_id = au.submission_id)':'')
-				. $this->getFetchJoins() .
-			' WHERE s.date_submitted IS NOT NULL AND
-				' . $this->getCompletionConditions(false) . ' AND
-				AND s.status <> ?
-				AND (SELECT COUNT(sa.stage_assignment_id) FROM stage_assignments sa
-					WHERE sa.submission_id = s.submission_id AND sa.user_id = ?) = 0
-				AND (SELECT COUNT(sa.stage_assignment_id) FROM stage_assignments sa LEFT JOIN user_groups g ON sa.user_group_id = g.user_group_id'
-					. ($editor?' LEFT JOIN users u ON (sa.user_id = u.user_id)':'')
-					. ' WHERE sa.submission_id = s.submission_id AND (g.role_id = ? OR g.role_id = ?)'
-					. ($editor?' AND ' . $this->_getEditorSearchQuery():'') . ') > 0'
-				. ($contextId?' AND s.context_id = ?':'')
-				. ($title?' AND (ss.setting_name = ? AND ss.setting_value LIKE ?)':'')
-				. ($author?' AND (au.first_name LIKE ? OR au.middle_name LIKE ? OR au.last_name LIKE ?)':'')
-				. ($stageId?' AND s.stage_id = ?':'') .
-			' GROUP BY ' . $this->getGroupByColumns(),
-			$params,
-			$rangeInfo
-		);
-
-		return new DAOResultFactory($result, $this, '_fromRow');
-	}
-
-	/**
-	 * Get all active submissions for a context.
-	 * @param $contextId int optional
-	 * @param $title string|null optional Filter by title.
-	 * @param $author string|null optional Filter by author.
-	 * @param $editor int|null optional Filter by editor name.
-	 * @param $stageId int|null optional Filter by stage id.
-	 * @param $rangeInfo DBResultRange optional
-	 * @return DAOResultFactory
-	 */
-	function getActiveSubmissions($contextId = null, $title = null, $author = null, $editor = null, $stageId = null, $rangeInfo = null) {
-		$params = $this->getFetchParameters();
-		$params[] = (int) STATUS_DECLINED;
-
-		if ($contextId) $params[] = (int) $contextId;
-
-		if ($title) {
-			$params[] = 'title';
-			$params[] = '%' . $title . '%';
-		}
-		if ($author) array_push($params, $authorQuery = '%' . $author . '%', $authorQuery, $authorQuery);
-		if ($stageId) $params[] = (int) $stageId;
-		if ($editor) array_push($params, (int) ROLE_ID_MANAGER, (int) ROLE_ID_SUB_EDITOR, $editorQuery = '%' . $editor . '%', $editorQuery);
-
-		$result = $this->retrieveRange(
-			'SELECT	s.*, ps.date_published,
-				' . $this->getFetchColumns() . '
-			FROM	submissions s
-				LEFT JOIN published_submissions ps ON (s.submission_id = ps.submission_id)
-				' . $this->getCompletionJoins() . '
-				' . ($title?' LEFT JOIN submission_settings ss ON (s.submission_id = ss.submission_id)':'') . '
-				' . ($author?' LEFT JOIN authors au ON (s.submission_id = au.submission_id)':'') . '
-				' . ($editor?' LEFT JOIN stage_assignments sa ON (s.submission_id = sa.submission_id)
-						LEFT JOIN user_groups g ON (sa.user_group_id = g.user_group_id)
-						LEFT JOIN users u ON (sa.user_id = u.user_id)':'') . '
-				' . $this->getFetchJoins() . '
-			WHERE	s.date_submitted IS NOT NULL
-				AND ' . $this->getCompletionConditions(false) . '
-				AND s.status <> ?
-				' . ($contextId?' AND s.context_id = ?':'') . '
-				' . ($title?' AND (ss.setting_name = ? AND ss.setting_value LIKE ?)':'') . '
-				' . ($author?' AND (au.first_name LIKE ? OR au.middle_name LIKE ? OR au.last_name LIKE ?)':'') . '
-				' . ($stageId?' AND s.stage_id = ?':'') . '
-				' . ($editor?' AND (g.role_id = ? OR g.role_id = ?) AND' . $this->_getEditorSearchQuery():'') .
-			' GROUP BY ' . $this->getGroupByColumns(),
-			$params,
-			$rangeInfo
+			' ORDER BY s.submission_id',
+			$params
 		);
 
 		return new DAOResultFactory($result, $this, '_fromRow');
@@ -860,6 +535,153 @@ abstract class SubmissionDAO extends DAO implements PKPPubIdPluginDAO {
 		$this->flushCache();
 	}
 
+	/**
+	 * Helper function to collect the SQL WHERE statement for searching
+	 * submissions by word(s)
+	 *
+	 * @param $phrase string The search phrase. One or more words.
+	 * @return string
+	 */
+	public function getSearchWhere($phrase) {
+		$searchWhere = '';
+		if ($phrase) {
+			$words = explode(" ", trim($phrase));
+			if (count($words)) {
+				$searchWhere = ' AND (';
+				$searchClauses = array();
+				foreach($words as $word) {
+					$clause = '(';
+					$clause .= '(ss.setting_name = ? AND ss.setting_value LIKE ?)';
+					$params[] = 'title';
+					$params[] = '%' . $word . '%';
+					$clause .= ' OR (asgs.setting_value LIKE ? OR asfs.setting_value LIKE ?)';
+					$params[] = '%' . $word . '%';
+					$params[] = '%' . $word . '%';
+					$searchClauses[] = $clause . ')';
+				}
+				$searchWhere .= join(' AND ', $searchClauses) . ')';
+			}
+		}
+
+		return $searchWhere;
+	}
+
+	/**
+	 * Associate a category with a submission.
+	 * @param $submissionId int
+	 * @param $categoryId int
+	 */
+	function addCategory($submissionId, $categoryId) {
+		$this->update(
+			'INSERT INTO submission_categories
+				(submission_id, category_id)
+			VALUES
+				(?, ?)',
+			array(
+				(int) $submissionId,
+				(int) $categoryId
+			)
+		);
+	}
+
+	/**
+	 * Unassociate a category with a submission.
+	 * @param $submissionId int
+	 * @param $categoryId int
+	 */
+	function removeCategory($submissionId, $categoryId) {
+		$this->update(
+			'DELETE FROM submission_categories WHERE submission_id = ? AND category_id = ?',
+			array(
+				(int) $submissionId,
+				(int) $categoryId
+			)
+		);
+	}
+
+	/**
+	 * Unassociate all categories.
+	 * @param $submissionId int
+	 */
+	function removeCategories($submissionId) {
+		$this->update(
+			'DELETE FROM submission_categories WHERE submission_id = ?',
+			(int) $submissionId
+		);
+	}
+
+	/**
+	 * Get the categories associated with a given submission.
+	 * @param $submissionId int The submission id.
+	 * @param $contextId int (optional) The submission's context id.
+	 * @return DAOResultFactory
+	 */
+	function getCategories($submissionId, $contextId = null) {
+		$params = array((int) $submissionId);
+		if ($contextId) $params[] = (int) $contextId;
+
+		$categoryDao = DAORegistry::getDAO('CategoryDAO');
+		$result = $this->retrieve(
+			'SELECT	c.*
+			FROM	categories c,
+				submission_categories sc,
+				submissions s
+			WHERE	c.category_id = sc.category_id AND
+				s.submission_id = ? AND
+			' . ($contextId?' c.context_id = s.context_id AND s.context_id = ? AND':'') . '
+				s.submission_id = sc.submission_id',
+			$params
+		);
+
+		// Delegate category creation to the category DAO.
+		return new DAOResultFactory($result, $categoryDao, '_fromRow');
+	}
+
+	/**
+	 * Get the categories not associated with a given submission.
+	 * @param $submissionId int
+	 * @return DAOResultFactory
+	 */
+	function getUnassignedCategories($submissionId, $contextId = null) {
+		$params = array((int) $submissionId);
+		if ($contextId) $params[] = (int) $contextId;
+
+		$categoryDao = DAORegistry::getDAO('CategoryDAO');
+		// The strange ORDER BY clause is to return subcategories
+		// immediately after their parent category's entry.
+		$result = $this->retrieve(
+			'SELECT	c.*
+			FROM	submissions s
+				JOIN categories c ON (c.context_id = s.context_id)
+				LEFT JOIN submission_categories sc ON (s.submission_id = sc.submission_id AND sc.category_id = c.category_id)
+			WHERE	s.submission_id = ? AND
+				' . ($contextId?' s.context_id = ? AND':'') . '
+				sc.submission_id IS NULL
+			ORDER BY CASE WHEN c.parent_id = 0 THEN c.category_id * 2 ELSE (c.parent_id * 2) + 1 END ASC',
+			$params
+		);
+
+		// Delegate category creation to the category DAO.
+		return new DAOResultFactory($result, $categoryDao, '_fromRow');
+	}
+
+	/**
+	 * Check if a submission exists in a category with the specified ID.
+	 * @param $submissionId int
+	 * @param $categoryId int
+	 * @return boolean
+	 */
+	function categoryAssociationExists($submissionId, $categoryId) {
+		$result = $this->retrieve(
+			'SELECT COUNT(*) FROM submission_categories WHERE submission_id = ? AND category_id = ?',
+			array((int) $submissionId, (int) $categoryId)
+		);
+		$returner = isset($result->fields[0]) && $result->fields[0] == 1 ? true : false;
+
+		$result->Close();
+		return $returner;
+	}
+
 
 	//
 	// Protected functions
@@ -920,16 +742,72 @@ abstract class SubmissionDAO extends DAO implements PKPPubIdPluginDAO {
 	 */
 	abstract protected function getCompletionConditions($completed);
 
-	//
-	// Private helper methods.
-	//
 	/**
-	 * Get the editor search query for submissions.
+	 * Get default sort option.
 	 * @return string
 	 */
-	private function _getEditorSearchQuery() {
-		return '(CONCAT_WS(\' \', u.first_name, u.middle_name, u.last_name) LIKE ? OR CONCAT_WS(\' \', u.first_name, u.last_name) LIKE ?)';
+	function getDefaultSortOption() {
+		return $this->getSortOption(ORDERBY_DATE_PUBLISHED, SORT_DIRECTION_DESC);
 	}
+
+	/**
+	 * Map a column heading value to a database value for sorting
+	 * @param $sortBy string
+	 * @return string
+	 */
+	function getSortMapping($sortBy) {
+		switch ($sortBy) {
+			case ORDERBY_TITLE:
+				return 'st.setting_value';
+			case ORDERBY_DATE_PUBLISHED:
+				return 'ps.date_published';
+			default: return null;
+		}
+	}
+
+	/**
+	 * Get possible sort options.
+	 * @return array
+	 */
+	function getSortSelectOptions() {
+		return array(
+			$this->getSortOption(ORDERBY_TITLE, SORT_DIRECTION_ASC) => __('catalog.sortBy.titleAsc'),
+			$this->getSortOption(ORDERBY_TITLE, SORT_DIRECTION_DESC) => __('catalog.sortBy.titleDesc'),
+			$this->getSortOption(ORDERBY_DATE_PUBLISHED, SORT_DIRECTION_ASC) => __('catalog.sortBy.datePublishedAsc'),
+			$this->getSortOption(ORDERBY_DATE_PUBLISHED, SORT_DIRECTION_DESC) => __('catalog.sortBy.datePublishedDesc'),
+		);
+	}
+
+	/**
+	 * Get sort option.
+	 * @param $sortBy string
+	 * @param $sortDir int
+	 * @return string
+	 */
+	function getSortOption($sortBy, $sortDir) {
+		return $sortBy .'-' . $sortDir;
+	}
+
+	/**
+	 * Get sort way for a sort option.
+	 * @param $sortOption string concat(sortBy, '-', sortDir)
+	 * @return string
+	 */
+	function getSortBy($sortOption) {
+		list($sortBy, $sortDir) = explode("-", $sortOption);
+		return $sortBy;
+	}
+
+	/**
+	 * Get sort direction for a sort option.
+	 * @param $sortOption string concat(sortBy, '-', sortDir)
+	 * @return int
+	 */
+	function getSortDirection($sortOption) {
+		list($sortBy, $sortDir) = explode("-", $sortOption);
+		return $sortDir;
+	}
+
 }
 
-?>
+
