@@ -3,8 +3,8 @@
 /**
  * @file classes/validation/ValidatorEmail.inc.php
  *
- * Copyright (c) 2014-2016 Simon Fraser University Library
- * Copyright (c) 2000-2016 John Willinsky
+ * Copyright (c) 2014-2019 Simon Fraser University
+ * Copyright (c) 2000-2019 John Willinsky
  * Distributed under the GNU GPL v2. For full terms see the file docs/COPYING.
  *
  * @class ValidatorEmail
@@ -20,8 +20,8 @@ class ValidatorEmail extends ValidatorRegExp {
 	/**
 	 * Constructor.
 	 */
-	function ValidatorEmail() {
-		parent::ValidatorRegExp(ValidatorEmail::getRegexp());
+	function __construct() {
+		parent::__construct(ValidatorEmail::getRegexp());
 	}
 
 
@@ -37,4 +37,4 @@ class ValidatorEmail extends ValidatorRegExp {
 	}
 }
 
-?>
+
