@@ -3,8 +3,8 @@
 /**
  * @file classes/validation/ValidatorISNI.inc.php
  *
- * Copyright (c) 2013-2016 Simon Fraser University Library
- * Copyright (c) 2000-2016 John Willinsky
+ * Copyright (c) 2013-2019 Simon Fraser University
+ * Copyright (c) 2000-2019 John Willinsky
  * Distributed under the GNU GPL v2. For full terms see the file docs/COPYING.
  *
  * @class ValidatorISNI
@@ -20,8 +20,8 @@ class ValidatorISNI extends ValidatorRegExp {
 	/**
 	 * Constructor.
 	 */
-	function ValidatorISNI() {
-		parent::ValidatorRegExp(self::getRegexp());
+	function __construct() {
+		parent::__construct(self::getRegexp());
 	}
 
 
@@ -63,4 +63,4 @@ class ValidatorISNI extends ValidatorRegExp {
 	}
 }
 
-?>
+
