@@ -3,8 +3,8 @@
 /**
  * @file controllers/grid/admin/context/ContextGridCellProvider.inc.php
  *
- * Copyright (c) 2014-2016 Simon Fraser University Library
- * Copyright (c) 2003-2016 John Willinsky
+ * Copyright (c) 2014-2019 Simon Fraser University
+ * Copyright (c) 2003-2019 John Willinsky
  * Distributed under the GNU GPL v2. For full terms see the file docs/COPYING.
  *
  * @class ContextGridCellProvider
@@ -16,12 +16,6 @@
 import('lib.pkp.classes.controllers.grid.GridCellProvider');
 
 class ContextGridCellProvider extends GridCellProvider {
-	/**
-	 * Constructor
-	 */
-	function ContextGridCellProvider() {
-		parent::GridCellProvider();
-	}
 
 	/**
 	 * Extracts variables for a given column from a data element
@@ -49,4 +43,4 @@ class ContextGridCellProvider extends GridCellProvider {
 	}
 }
 
-?>
+
