@@ -3,8 +3,8 @@
 /**
  * @file controllers/grid/admin/systemInfo/SystemInfoGridCategoryRow.inc.php
  *
- * Copyright (c) 2014-2016 Simon Fraser University Library
- * Copyright (c) 2000-2016 John Willinsky
+ * Copyright (c) 2014-2019 Simon Fraser University
+ * Copyright (c) 2000-2019 John Willinsky
  * Distributed under the GNU GPL v2. For full terms see the file docs/COPYING.
  *
  * @class SystemInfoGridCategoryRow
@@ -19,12 +19,6 @@ class SystemInfoGridCategoryRow extends GridCategoryRow {
 
 	var $_configSection;
 
-	/**
-	 * Constructor
-	 */
-	function SystemInfoGridCategoryRow() {
-		parent::GridCategoryRow();
-	}
 
 	//
 	// Overridden methods from GridCategoryRow
@@ -33,9 +27,9 @@ class SystemInfoGridCategoryRow extends GridCategoryRow {
 	 * @see GridCategoryRow::initialize()
 	 * @param $request PKPRequest
 	 */
-	function initialize($request) {
+	function initialize($request, $template = null) {
 		// Do the default initialization
-		parent::initialize($request);
+		parent::initialize($request, $template);
 		$this->_configSection = $this->getData();
 	}
 
@@ -47,4 +41,4 @@ class SystemInfoGridCategoryRow extends GridCategoryRow {
 		return $this->_configSection;
 	}
 }
-?>
+
