@@ -3,8 +3,8 @@
 /**
  * @file pages/about/AboutSiteHandler.inc.php
  *
- * Copyright (c) 2014-2016 Simon Fraser University Library
- * Copyright (c) 2003-2016 John Willinsky
+ * Copyright (c) 2014-2019 Simon Fraser University
+ * Copyright (c) 2003-2019 John Willinsky
  * Distributed under the GNU GPL v2. For full terms see the file docs/COPYING.
  *
  * @class AboutSiteHandler
@@ -19,9 +19,9 @@ class AboutSiteHandler extends Handler {
 	/**
 	 * Constructor
 	 */
-	function AboutSiteHandler() {
-		parent::Handler();
-		AppLocale::requireComponents(LOCALE_COMPONENT_APP_COMMON);
+	function __construct() {
+		parent::__construct();
+		AppLocale::requireComponents(LOCALE_COMPONENT_APP_COMMON, LOCALE_COMPONENT_PKP_USER, LOCALE_COMPONENT_PKP_MANAGER);
 	}
 
 	/**
@@ -44,6 +44,28 @@ class AboutSiteHandler extends Handler {
 
 		$templateMgr->display('frontend/pages/aboutThisPublishingSystem.tpl');
 	}
-}
 
-?>
+	/**
+	 * Display privacy policy page.
+	 * @param $args array
+	 * @param $request PKPRequest
+	 */
+	function privacy($args, $request) {
+		$templateMgr = TemplateManager::getManager($request);
+		$this->setupTemplate($request);
+		$context = $request->getContext();
+		$enableSiteWidePrivacyStatement = Config::getVar('general', 'sitewide_privacy_statement');
+		if (!$enableSiteWidePrivacyStatement && $context) {
+			$privacyStatement = $context->getLocalizedSetting('privacyStatement');
+		} else {
+			$privacyStatement = $request->getSite()->getLocalizedSetting('privacyStatement');
+		}
+		if (!$privacyStatement) {
+			$dispatcher = $this->getDispatcher();
+			$dispatcher->handle404();
+		}
+		$templateMgr->assign('privacyStatement', $privacyStatement);
+
+		$templateMgr->display('frontend/pages/privacy.tpl');
+	}
+}
