@@ -3,8 +3,8 @@
 /**
  * @file pages/management/ManagementHandler.inc.php
  *
- * Copyright (c) 2013-2016 Simon Fraser University Library
- * Copyright (c) 2003-2016 John Willinsky
+ * Copyright (c) 2013-2019 Simon Fraser University
+ * Copyright (c) 2003-2019 John Willinsky
  * Distributed under the GNU GPL v2. For full terms see the file docs/COPYING.
  *
  * @class ManagementHandler
@@ -17,13 +17,6 @@
 import('classes.handler.Handler');
 
 class ManagementHandler extends Handler {
-	/**
-	 * Constructor.
-	 */
-	function ManagementHandler() {
-		parent::Handler();
-	}
-
 
 	//
 	// Overridden methods from Handler
@@ -31,8 +24,8 @@ class ManagementHandler extends Handler {
 	/**
 	 * @see PKPHandler::initialize()
 	 */
-	function initialize($request, $args = null) {
-		parent::initialize($request, $args);
+	function initialize($request) {
+		parent::initialize($request);
 
 		// Load manager locale components.
 		AppLocale::requireComponents(LOCALE_COMPONENT_PKP_MANAGER, LOCALE_COMPONENT_APP_MANAGER, LOCALE_COMPONENT_PKP_GRID);
@@ -51,4 +44,4 @@ class ManagementHandler extends Handler {
 	}
 }
 
-?>
+
