@@ -6,8 +6,8 @@
 /**
  * @file plugins/metadata/dc11/PKPDc11MetadataPlugin.inc.php
  *
- * Copyright (c) 2014-2016 Simon Fraser University Library
- * Copyright (c) 2003-2016 John Willinsky
+ * Copyright (c) 2014-2019 Simon Fraser University
+ * Copyright (c) 2003-2019 John Willinsky
  * Distributed under the GNU GPL v2. For full terms see the file docs/COPYING.
  *
  * @class PKPDc11MetadataPlugin
@@ -20,13 +20,6 @@
 import('lib.pkp.classes.plugins.MetadataPlugin');
 
 class PKPDc11MetadataPlugin extends MetadataPlugin {
-	/**
-	 * Constructor
-	 */
-	function PKPDc11MetadataPlugin() {
-		parent::MetadataPlugin();
-	}
-
 
 	//
 	// Override protected template methods from Plugin
@@ -51,6 +44,22 @@ class PKPDc11MetadataPlugin extends MetadataPlugin {
 	function getDescription() {
 		return __('plugins.metadata.dc11.description');
 	}
+
+	/**
+	 * @copydoc MetadataPlugin::supportsFormat()
+	 */
+	public function supportsFormat($format) {
+		return $format === 'dc11';
+	}
+
+	/**
+	 * @copydoc MetadataPlugin::getSchemaObject()
+	 */
+	public function getSchemaObject($format) {
+		assert($this->supportsFormat($format));
+		import('plugins.metadata.dc11.schema.Dc11Schema');
+		return new Dc11Schema();
+	}
 }
 
-?>
+
