@@ -7,8 +7,8 @@
 /**
  * @file pages/payment/index.php
  *
- * Copyright (c) 2014-2016 Simon Fraser University Library
- * Copyright (c) 2003-2016 John Willinsky
+ * Copyright (c) 2014-2019 Simon Fraser University
+ * Copyright (c) 2003-2019 John Willinsky
  * Distributed under the GNU GPL v2. For full terms see the file docs/COPYING.
  *
  * @ingroup pages_payment
@@ -18,9 +18,10 @@
 
 switch ($op) {
 	case 'plugin':
+	case 'pay':
 		define('HANDLER_CLASS', 'PaymentHandler');
 		import('pages.payment.PaymentHandler');
 		break;
 }
 
-?>
+
