@@ -3,8 +3,8 @@
 /**
  * @file plugins/importexport/native/filter/NativeXmlArticleFileFilter.inc.php
  *
- * Copyright (c) 2014-2016 Simon Fraser University Library
- * Copyright (c) 2000-2016 John Willinsky
+ * Copyright (c) 2014-2019 Simon Fraser University
+ * Copyright (c) 2000-2019 John Willinsky
  * Distributed under the GNU GPL v2. For full terms see the file docs/COPYING.
  *
  * @class NativeXmlArticleFileFilter
@@ -20,8 +20,8 @@ class NativeXmlArticleFileFilter extends NativeXmlSubmissionFileFilter {
 	 * Constructor
 	 * @param $filterGroup FilterGroup
 	 */
-	function NativeXmlArticleFileFilter($filterGroup) {
-		parent::NativeXmlSubmissionFileFilter($filterGroup);
+	function __construct($filterGroup) {
+		parent::__construct($filterGroup);
 	}
 
 
@@ -36,4 +36,4 @@ class NativeXmlArticleFileFilter extends NativeXmlSubmissionFileFilter {
 	}
 }
 
-?>
+
