@@ -3,8 +3,8 @@
 /**
  * @file plugins/oaiMetadataFormats/marcxml/OAIMetadataFormat_MARC21.inc.php
  *
- * Copyright (c) 2014-2016 Simon Fraser University Library
- * Copyright (c) 2003-2016 John Willinsky
+ * Copyright (c) 2014-2019 Simon Fraser University
+ * Copyright (c) 2003-2019 John Willinsky
  * Distributed under the GNU GPL v2. For full terms see the file docs/COPYING.
  *
  * @class OAIMetadataFormat_MARC21
@@ -18,7 +18,7 @@ class OAIMetadataFormat_MARC21 extends OAIMetadataFormat {
 	/**
 	 * @see OAIMetadataFormat#toXml
 	 */
-	function toXml(&$record, $format = null) {
+	function toXml($record, $format = null) {
 		$article = $record->getData('article');
 		$journal = $record->getData('journal');
 
@@ -31,8 +31,8 @@ class OAIMetadataFormat_MARC21 extends OAIMetadataFormat {
 		));
 
 		$subjects = array_merge_recursive(
-			$this->stripAssocArray((array) $article->getDiscipline(null)),
-			$this->stripAssocArray((array) $article->getSubject(null))
+			stripAssocArray((array) $article->getDiscipline(null)),
+			stripAssocArray((array) $article->getSubject(null))
 		);
 
 		$templateMgr->assign(array(
@@ -41,8 +41,9 @@ class OAIMetadataFormat_MARC21 extends OAIMetadataFormat {
 			'language' => AppLocale::get3LetterIsoFromLocale($article->getLocale())
 		));
 
-		return $templateMgr->fetch(dirname(__FILE__) . '/record.tpl');
+		$plugin = PluginRegistry::getPlugin('oaiMetadataFormats', 'OAIFormatPlugin_MARC21');
+		return $templateMgr->fetch($plugin->getTemplateResource('record.tpl'));
 	}
 }
 
-?>
+
